AudioTrackInfo class

Inheritance

Constructors

AudioTrackInfo({required AudioCodec codec, required int sampleRate, required int channels, CodecExtraData? extraData})
const

Properties

channels int
final
codec AudioCodec
final
extraData CodecExtraData?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited