MiniAVBufferSource class

Inheritance

Constructors

MiniAVBufferSource(MiniAVBuffer buffer)
const

Properties

buffer MiniAVBuffer
final
hashCode int
The hash code for this object.
no setterinherited
height int
Frame height in pixels.
no setteroverride
kind FrameSourceKind
What kind this is, for backend capability checks.
no setteroverride
pixelFormat MiniAVPixelFormat
Pixel format. Backends may need to perform color-space conversion.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestampUs int
Presentation timestamp in microseconds. May be 0 if unknown.
no setteroverride
width int
Frame width in pixels.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited