CodecExtraData class
Codec-private bitstream extras (SPS/PPS for H.264, codec-private for VP9, etc.) emitted once at stream start. Muxers need this to write track headers.
Constructors
- CodecExtraData.audio(AudioCodec? audioCodec, Uint8List bytes)
-
const
- CodecExtraData.video(VideoCodec? videoCodec, Uint8List bytes)
-
const
Properties
- audioCodec → AudioCodec?
-
final
- bytes → Uint8List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- videoCodec → VideoCodec?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited